Crate solana_builtins_default_costs

Crate solana_builtins_default_costs 

👎Deprecated since 3.1.0:

This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Structs

MigratingBuiltinCostDeprecated

Enums

BuiltinCostDeprecated
DEVELOPER: when a builtin is migrated to sbpf, please add its corresponding migration feature ID to BUILTIN_INSTRUCTION_COSTS, and move it from NON_MIGRATING_BUILTINS_COSTS to MIGRATING_BUILTINS_COSTS, so the builtin’s default cost can be determined properly based on feature status. When migration completed, eg the feature gate is enabled everywhere, please remove that builtin entry from MIGRATING_BUILTINS_COSTS.
BuiltinMigrationFeatureIndexDeprecated

Constants

MIGRATING_BUILTINS_COSTSDeprecated
MIGRATING_BUILTINS_COSTS is empty as no builtins are presently being migrated. We leave it and the related scaffolding in place for future planned migrations.

Statics

MAYBE_BUILTIN_KEYDeprecated
A table of 256 booleans indicates whether the first u8 of a Pubkey exists in BUILTIN_INSTRUCTION_COSTS. If the value is true, the Pubkey might be a builtin key; if false, it cannot be a builtin key. This table allows for quick filtering of builtin program IDs without the need for hashing.

Functions

get_builtin_migration_feature_indexDeprecated
get_migration_feature_idDeprecated
Helper function to return ref of migration feature Pubkey at position index from MIGRATING_BUILTINS_COSTS