👎Deprecated since 3.1.0:
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Structs
- Migrating
Builtin Cost Deprecated
Enums
- Builtin
Cost Deprecated - DEVELOPER: when a builtin is migrated to sbpf, please add its corresponding migration feature ID to BUILTIN_INSTRUCTION_COSTS, and move it from NON_MIGRATING_BUILTINS_COSTS to MIGRATING_BUILTINS_COSTS, so the builtin’s default cost can be determined properly based on feature status. When migration completed, eg the feature gate is enabled everywhere, please remove that builtin entry from MIGRATING_BUILTINS_COSTS.
- Builtin
Migration Feature Index Deprecated
Constants
- MIGRATING_
BUILTINS_ COSTS Deprecated - MIGRATING_BUILTINS_COSTS is empty as no builtins are presently being migrated. We leave it and the related scaffolding in place for future planned migrations.
Statics
- MAYBE_
BUILTIN_ KEY Deprecated - A table of 256 booleans indicates whether the first
u8of a Pubkey exists in BUILTIN_INSTRUCTION_COSTS. If the value is true, the Pubkey might be a builtin key; if false, it cannot be a builtin key. This table allows for quick filtering of builtin program IDs without the need for hashing.
Functions
- get_
builtin_ migration_ feature_ index Deprecated - get_
migration_ feature_ id Deprecated - Helper function to return ref of migration feature Pubkey at position
indexfrom MIGRATING_BUILTINS_COSTS